
flax.serialization package
============================

.. currentmodule:: flax.serialization

.. automodule:: flax.serialization


State dicts
------------------------

.. autofunction:: from_state_dict
.. autofunction:: to_state_dict

.. autofunction:: register_serialization_state


Serialization with MessagePack
--------------------------------

.. autofunction:: msgpack_serialize
.. autofunction:: msgpack_restore

.. autofunction:: to_bytes
.. autofunction:: from_bytes
